"""
Arborium: A tree visualization and analysis package.

Arborium is designed to make tree-based models more interpretable and
easier to understand through advanced visualization techniques.
"""

from .visualizer import XGBTreeVisualizer

__version__ = '0.1.4'
__all__ = ['XGBTreeVisualizer'] 